Learn R Programming

oc (version 1.2.1)

summary.OCobject: Optimal Classification Summary

Description

summary.OCobject reads an Optimal Classification object and prints a summary.

Usage

# S3 method for OCobject
summary(object,verbose=FALSE,...)

Value

A summary of a OCobject object.

Arguments

object

an OCobject output object.

verbose

logical, includes all ideal points if TRUE, otherwise only returns the first 10 legislators.

...

other arguments do nothing and are not passed to any functions.

Author

Keith Poole [email protected]

Jeffrey Lewis [email protected]

James Lo [email protected]

Royce Carroll [email protected]

See Also

'oc', 'plot.OCcoords', 'plot.OCskree', 'plot.OCangles', 'plot.OCcutlines', 'plot.OCobject'

Examples

Run this code
    #This data file is the same as that obtained using:
    if (FALSE) {
    data(sen90)
    sen90oc <- oc(sen90,dims=2,polarity=c(7,2)) 
	}

    data(sen90oc)
    summary(sen90oc)
    plot(sen90oc)

Run the code above in your browser using DataLab